.. _shorewall_module:

:mod:`fabtools.shorewall`
-------------------------

.. automodule:: fabtools.shorewall

    .. seealso:: :ref:`require_shorewall_module`

    Firewall status
    ~~~~~~~~~~~~~~~

    .. autofunction:: status
    .. autofunction:: is_started
    .. autofunction:: is_stopped

    Firewall rules
    ~~~~~~~~~~~~~~

    .. autofunction:: rule
    .. autofunction:: hosts
    .. autofunction:: Ping
    .. autofunction:: SSH
    .. autofunction:: HTTP
    .. autofunction:: HTTPS
    .. autofunction:: SMTP
